
# Slot: slot_conditions


the redefinition of a slot in the context of the containing class definition.

URI: [linkml:slot_conditions](https://w3id.org/linkml/slot_conditions)


## Domain and Range

None &#8594;  <sub>0..\*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [AnonymousClassExpression](AnonymousClassExpression.md)
 * [ClassDefinition](ClassDefinition.md)
 * [ClassExpression](ClassExpression.md)
